@@ -390,7 +390,7 @@ func (ps *pageState) initCommonProviders(pp pagePaths) error {
 	return nil
 }
 
-func (p *pageState) createRenderHooks(f output.Format) (*hooks.Renderers, error) {
+func (p *pageState) createRenderHooks(f output.Format) (hooks.Renderers, error) {
 	layoutDescriptor := p.getLayoutDescriptor()
 	layoutDescriptor.RenderingHook = true
 	layoutDescriptor.LayoutOverride = false
@@ -401,7 +401,7 @@ func (p *pageState) createRenderHooks(f output.Format) (*hooks.Renderers, error)
 	layoutDescriptor.Kind = "render-link"
 	templ, templFound, err := p.s.Tmpl().LookupLayout(layoutDescriptor, f)
 	if err != nil {
-		return nil, err
+		return renderers, err
 	}
 	if templFound {
 		renderers.LinkRenderer = hookRenderer{
@@ -414,7 +414,7 @@ func (p *pageState) createRenderHooks(f output.Format) (*hooks.Renderers, error)
 	layoutDescriptor.Kind = "render-image"
 	templ, templFound, err = p.s.Tmpl().LookupLayout(layoutDescriptor, f)
 	if err != nil {
-		return nil, err
+		return renderers, err
 	}
 	if templFound {
 		renderers.ImageRenderer = hookRenderer{
@@ -427,7 +427,7 @@ func (p *pageState) createRenderHooks(f output.Format) (*hooks.Renderers, error)
 	layoutDescriptor.Kind = "render-heading"
 	templ, templFound, err = p.s.Tmpl().LookupLayout(layoutDescriptor, f)
 	if err != nil {
-		return nil, err
+		return renderers, err
 	}
 	if templFound {
 		renderers.HeadingRenderer = hookRenderer{
@@ -437,7 +437,7 @@ func (p *pageState) createRenderHooks(f output.Format) (*hooks.Renderers, error)
 		}
 	}
 
-	return &renderers, nil
+	return renderers, nil
 }
 
 func (p *pageState) getLayoutDescriptor() output.LayoutDescriptor {
