@@ -34,7 +34,7 @@ func TestNew(t *testing.T) {
 	var rawJS string
 	var minJS string
 	rawJS = " var  foo =1 ;   foo ++  ;  "
-	minJS = "var foo=1;foo++;"
+	minJS = "var foo=1;foo++"
 
 	var rawJSON string
 	var minJSON string
@@ -158,6 +158,8 @@ func TestBugs(t *testing.T) {
 	}{
 		// https://github.com/gohugoio/hugo/issues/5506
 		{media.CSSType, " body { color: rgba(000, 000, 000, 0.7); }", "body{color:rgba(0,0,0,.7)}"},
+		// https://github.com/gohugoio/hugo/issues/8332
+		{media.HTMLType, "<i class='fas fa-tags fa-fw'></i> Tags", `<i class="fas fa-tags fa-fw"></i> Tags`},
 	} {
 		var b bytes.Buffer
 
@@ -165,3 +167,26 @@ func TestBugs(t *testing.T) {
 		c.Assert(b.String(), qt.Equals, test.expectedMinString)
 	}
 }
+
+// Renamed to Precision in v2.7.0. Check that we support both.
+func TestDecodeConfigDecimalIsNowPrecision(t *testing.T) {
+	c := qt.New(t)
+	v := viper.New()
+	v.Set("minify", map[string]interface{}{
+		"disablexml": true,
+		"tdewolff": map[string]interface{}{
+			"css": map[string]interface{}{
+				"decimal": 3,
+			},
+			"svg": map[string]interface{}{
+				"decimal": 3,
+			},
+		},
+	})
+
+	conf, err := decodeConfig(v)
+
+	c.Assert(err, qt.IsNil)
+	c.Assert(conf.Tdewolff.CSS.Precision, qt.Equals, 3)
+
+}
