@@ -19,6 +19,7 @@ import (
 	"path/filepath"
 	"reflect"
 	"regexp"
+	"sort"
 	"strings"
 	"sync"
 	"time"
@@ -138,7 +139,7 @@ func newTemplateExec(d *deps.Deps) (*templateExec, error) {
 		baseof:       make(map[string]templateInfo),
 		needsBaseof:  make(map[string]templateInfo),
 
-		main: newTemplateNamespace(funcMap, false),
+		main: newTemplateNamespace(funcMap),
 
 		Deps:                d,
 		layoutHandler:       output.NewLayoutHandler(),
@@ -167,24 +168,17 @@ func newTemplateExec(d *deps.Deps) (*templateExec, error) {
 	if d.WithTemplate != nil {
 		if err := d.WithTemplate(e); err != nil {
 			return nil, err
-
 		}
 	}
 
 	return e, nil
 }
 
-func newTemplateNamespace(funcs map[string]interface{}, lock bool) *templateNamespace {
-	var mu *sync.RWMutex
-	if lock {
-		mu = &sync.RWMutex{}
-	}
-
+func newTemplateNamespace(funcs map[string]interface{}) *templateNamespace {
 	return &templateNamespace{
 		prototypeHTML: htmltemplate.New("").Funcs(funcs),
 		prototypeText: texttemplate.New("").Funcs(funcs),
 		templateStateMap: &templateStateMap{
-			mu:        mu,
 			templates: make(map[string]*templateState),
 		},
 	}
@@ -252,7 +246,6 @@ func (t *templateExec) MarkReady() error {
 	})
 
 	return err
-
 }
 
 type templateHandler struct {
@@ -351,7 +344,6 @@ func (t *templateHandler) LookupVariant(name string, variants tpl.TemplateVarian
 	more := len(s.variants) > 1
 
 	return sv.ts, true, more
-
 }
 
 // LookupVariants returns all variants of name, nil if none found.
@@ -368,11 +360,9 @@ func (t *templateHandler) LookupVariants(name string) []tpl.Template {
 	}
 
 	return variants
-
 }
 
 func (t *templateHandler) HasTemplate(name string) bool {
-
 	if _, found := t.baseof[name]; found {
 		return true
 	}
@@ -426,6 +416,10 @@ func (t *templateHandler) findLayout(d output.LayoutDescriptor, f output.Format)
 
 		t.applyTemplateTransformers(t.main, ts)
 
+		if err := t.extractPartials(ts.Template); err != nil {
+			return nil, false, err
+		}
+
 		return ts, true, nil
 
 	}
@@ -503,7 +497,6 @@ func (t *templateHandler) addFileContext(templ tpl.Template, inerr error) error
 	err, _ := checkFilename(ts.baseInfo, inerr)
 
 	return err
-
 }
 
 func (t *templateHandler) addShortcodeVariant(ts *templateState) {
@@ -570,24 +563,12 @@ func (t *templateHandler) addTemplateFile(name, path string) error {
 	if isBaseTemplatePath(name) {
 		// Store it for later.
 		t.baseof[name] = tinfo
-		// Also parse and add it on its own to make sure we reach the inline partials.
-		tinfo.name = name + ".___b"
-		_, err := t.addTemplateTo(tinfo, t.main)
-		if err != nil {
-			return tinfo.errWithFileContext("parse failed", err)
-		}
 		return nil
 	}
 
 	needsBaseof := !t.noBaseNeeded(name) && needsBaseTemplate(tinfo.template)
 	if needsBaseof {
 		t.needsBaseof[name] = tinfo
-		// Also parse and add it on its own to make sure we reach the inline partials.
-		tinfo.name = name + ".___b"
-		_, err := t.addTemplateTo(tinfo, t.main)
-		if err != nil {
-			return tinfo.errWithFileContext("parse failed", err)
-		}
 		return nil
 	}
 
@@ -598,7 +579,6 @@ func (t *templateHandler) addTemplateFile(name, path string) error {
 	t.applyTemplateTransformers(t.main, templ)
 
 	return nil
-
 }
 
 func (t *templateHandler) addTemplateTo(info templateInfo, to *templateNamespace) (*templateState, error) {
@@ -619,10 +599,16 @@ func (t *templateHandler) applyBaseTemplate(overlay, base templateInfo) (tpl.Tem
 			}
 		}
 
-		templ, err = templ.Parse(overlay.template)
+		templ, err = texttemplate.Must(templ.Clone()).Parse(overlay.template)
 		if err != nil {
 			return nil, overlay.errWithFileContext("parse failed", err)
 		}
+
+		// The extra lookup is a workaround, see
+		// * https://github.com/golang/go/issues/16101
+		// * https://github.com/gohugoio/hugo/issues/2549
+		// templ = templ.Lookup(templ.Name())
+
 		return templ, nil
 	}
 
@@ -730,7 +716,6 @@ func (t *templateHandler) loadTemplates() error {
 	}
 
 	return nil
-
 }
 
 func (t *templateHandler) nameIsText(name string) (string, bool) {
@@ -748,6 +733,37 @@ func (t *templateHandler) noBaseNeeded(name string) bool {
 	return strings.Contains(name, "_markup/")
 }
 
+func (t *templateHandler) extractPartials(templ tpl.Template) error {
+	templs := templates(templ)
+	for _, templ := range templs {
+		if templ.Name() == "" || !strings.HasPrefix(templ.Name(), "partials/") {
+			continue
+		}
+
+		ts := newTemplateState(templ, templateInfo{name: templ.Name()})
+		ts.typ = templatePartial
+
+		t.main.mu.RLock()
+		_, found := t.main.templates[templ.Name()]
+		t.main.mu.RUnlock()
+
+		if !found {
+			t.main.mu.Lock()
+			// This is a template defined inline.
+			_, err := applyTemplateTransformers(ts, t.main.newTemplateLookup(ts))
+			if err != nil {
+				t.main.mu.Unlock()
+				return err
+			}
+			t.main.templates[templ.Name()] = ts
+			t.main.mu.Unlock()
+
+		}
+	}
+
+	return nil
+}
+
 func (t *templateHandler) postTransform() error {
 	defineCheckedHTML := false
 	defineCheckedText := false
@@ -774,25 +790,8 @@ func (t *templateHandler) postTransform() error {
 			defineCheckedHTML = true
 		}
 
-		templs := templates(v.Template)
-		for _, templ := range templs {
-			if templ.Name() == "" || !strings.HasPrefix(templ.Name(), "partials/") {
-				continue
-			}
-
-			ts := newTemplateState(templ, templateInfo{name: templ.Name()})
-			ts.typ = templatePartial
-
-			if _, found := t.main.templates[templ.Name()]; !found {
-				// This is a template defined inline.
-
-				_, err := applyTemplateTransformers(ts, t.main.newTemplateLookup(ts))
-				if err != nil {
-					return err
-				}
-				t.main.templates[templ.Name()] = ts
-
-			}
+		if err := t.extractPartials(v.Template); err != nil {
+			return err
 		}
 	}
 
@@ -816,6 +815,24 @@ func (t *templateHandler) postTransform() error {
 		}
 	}
 
+	for _, v := range t.shortcodes {
+		sort.Slice(v.variants, func(i, j int) bool {
+			v1, v2 := v.variants[i], v.variants[j]
+			name1, name2 := v1.ts.Name(), v2.ts.Name()
+			isHTMl1, isHTML2 := strings.HasSuffix(name1, "html"), strings.HasSuffix(name2, "html")
+
+			// There will be a weighted selection later, but make
+			// sure these are sorted to get a stable selection for
+			// output formats missing specific templates.
+			// Prefer HTML.
+			if isHTMl1 || isHTML2 && !(isHTMl1 && isHTML2) {
+				return isHTMl1
+			}
+
+			return name1 < name2
+		})
+	}
+
 	return nil
 }
 
@@ -828,20 +845,12 @@ type templateNamespace struct {
 	*templateStateMap
 }
 
-func (t templateNamespace) Clone(lock bool) *templateNamespace {
-	if t.mu != nil {
-		t.mu.Lock()
-		defer t.mu.Unlock()
-	}
-
-	var mu *sync.RWMutex
-	if lock {
-		mu = &sync.RWMutex{}
-	}
+func (t templateNamespace) Clone() *templateNamespace {
+	t.mu.Lock()
+	defer t.mu.Unlock()
 
 	t.templateStateMap = &templateStateMap{
 		templates: make(map[string]*templateState),
-		mu:        mu,
 	}
 
 	t.prototypeText = texttemplate.Must(t.prototypeText.Clone())
@@ -851,20 +860,14 @@ func (t templateNamespace) Clone(lock bool) *templateNamespace {
 }
 
 func (t *templateNamespace) Lookup(name string) (tpl.Template, bool) {
-	if t.mu != nil {
-		t.mu.RLock()
-		defer t.mu.RUnlock()
-	}
+	t.mu.RLock()
+	defer t.mu.RUnlock()
 
 	templ, found := t.templates[name]
 	if !found {
 		return nil, false
 	}
 
-	if t.mu != nil {
-		return &templateWrapperWithLock{RWMutex: t.mu, Template: templ}, true
-	}
-
 	return templ, found
 }
 
@@ -887,15 +890,12 @@ func (t *templateNamespace) newTemplateLookup(in *templateState) func(name strin
 			return newTemplateState(templ, templateInfo{name: templ.Name()})
 		}
 		return nil
-
 	}
 }
 
 func (t *templateNamespace) parse(info templateInfo) (*templateState, error) {
-	if t.mu != nil {
-		t.mu.Lock()
-		defer t.mu.Unlock()
-	}
+	t.mu.Lock()
+	defer t.mu.Unlock()
 
 	if info.isText {
 		prototype := t.prototypeText
@@ -948,11 +948,10 @@ func (t *templateState) isText() bool {
 func isText(templ tpl.Template) bool {
 	_, isText := templ.(*texttemplate.Template)
 	return isText
-
 }
 
 type templateStateMap struct {
-	mu        *sync.RWMutex // May be nil
+	mu        sync.RWMutex
 	templates map[string]*templateState
 }
 
@@ -1018,7 +1017,6 @@ func removeLeadingBOM(s string) string {
 	}
 
 	return s
-
 }
 
 // resolves _internal/shortcodes/param.html => param.html etc.
@@ -1030,7 +1028,6 @@ func templateBaseName(typ templateType, name string) string {
 	default:
 		panic("not implemented")
 	}
-
 }
 
 func unwrap(templ tpl.Template) tpl.Template {
@@ -1056,5 +1053,4 @@ func templates(in tpl.Template) []tpl.Template {
 	}
 
 	return templs
-
 }
